"""Documentation about dissector."""

import logging

logging.getLogger(__name__).addHandler(logging.NullHandler())

__author__ = "Candace Makeda Moore"
__email__ = "doctormakeda@gmail.com"
__version__ = "0.0.1"
